.deletelink {
  color: var(--button-fg) !important;
  height: initial !important;
}

.modal-dialog {
  margin-top: 100px;
}

.modal-body {
  padding: 0 !important;
  height: 400px;
  min-height: 400px;
  overflow: hidden;
}

.modal-title {
  margin: 0;
  font-size: 1.25rem;
  color: #1a1e21;
}

.image-field {
  display: none;
}

#show-image {
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  width: 148px;
  height: 148px;
  background-color: rgba(0, 0, 0, .1);
  border-radius: 6px;
}

#show-image > img {
  display: block;
  max-width: 100%;
  max-height: 100%;
}

#show-image:hover #mask {
  display: block;
}

#mask {
  display: none;
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, .5);
  color: #fff;
  font-size: 24px;
  line-height: 148px;
  text-align: center;
  z-index: 999;
}

#add-image {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 148px;
  height: 148px;
  border: 1px dashed #c0ccda;
  border-radius: 6px;
  box-sizing: border-box;
  cursor: pointer;
  font-size: 28px;
  color: #8c939d;
}

#mask > i {
  cursor: pointer;
}

#add-image:hover {
  border-color: #409EFF;
  color: #409EFF;
}

#deleteBtn:hover {
  color: red
}
